{ lib, inputs, nixpkgs, home-manager, user, ... }:

let
  system = "x86_64-linux";
  pkgs = import nixpkgs {
    inherit system;
    config.allowUnfree = true;
  };
  lib = nixpkgs.lib;
in
{
  elnupad = lib.nixosSystem {
    inherit system;
    specialArgs = { inherit user; };
    modules = [
      ./elnupad
      ./configuration.nix
      ./desktop.nix
      home-manager.nixosModules.home-manager {
        home-manager.useGlobalPkgs = true;
        home-manager.useUserPackages = true;
        home-manager.extraSpecialArgs = { inherit user; };
        home-manager.users.${user} = {
          imports = [
            (import ./home.nix)
            (import ./elnupad/home.nix)
          ];
        };
      }
    ];
  };

  virtualbox = lib.nixosSystem {
    inherit system;
    specialArgs = { inherit user; };
    modules = [
      ./virtualbox
      ./configuration.nix
      ./desktop.nix
      home-manager.nixosModules.home-manager {
        home-manager.useGlobalPkgs = true;
        home-manager.useUserPackages = true;
        home-manager.extraSpecialArgs = { inherit user; };
        home-manager.users.${user} = {
          imports = [
            (import ./home.nix)
            (import ./virtualbox/home.nix)
          ];
        };
      }
    ];
  };
}
