{ config, pkgs, user, ... }:

{
  imports = [
    ../vim.nix
    ../wallpaper.nix
    ../picom.nix
    ../i3.nix
    ../polybar
    ../rofi
    ../git.nix
    ../terminal.nix
  ];

  programs.home-manager.enable = true;

  gtk = {
    enable = true;
    iconTheme = {
      name = "Nordic";
      package = pkgs.nordic;
    };
    theme = {
      name = "Nordic";
      package = pkgs.nordic;
    };
    gtk3.extraConfig = {
      # Remove minimize, maximize, and close buttons
      gtk-decoration-layout = "appmenu:none";
    };
  };

  home = {
    username = "${user}";
    homeDirectory = "/home/${user}";

    stateVersion = "22.05";

    packages = with pkgs; [
      # Command line utilities
      wget
      neofetch
      ranger
      trash-cli # aliased to rm in .bashrc

      # GUI applications
      firefox
      discord
      gnome.nautilus
    ];

    file = {
      ".bashrc" = {
        source = ../.bashrc;
      };
    };

    sessionVariables = {
      EDITOR = "vim";
    };
  };
}
